%define build_gssapi 1
%define build_ldap 1
%define build_lucene 1
%define build_mysql 1
%define build_pgsql 1
%define build_sasl 1

%{?_with_gssapi: %{expand: %%global build_gssapi 1}}
%{?_without_gssapi: %{expand: %%global build_gssapi 0}}
%{?_with_ldap: %{expand: %%global build_ldap 1}}
%{?_without_ldap: %{expand: %%global build_ldap 0}}
%{?_with_lucene: %{expand: %%global build_lucene 1}}
%{?_without_lucene: %{expand: %%global build_lucene 0}}
%{?_with_mysql: %{expand: %%global build_mysql 1}}
%{?_without_mysql: %{expand: %%global build_mysql 0}}
%{?_with_pgsql: %{expand: %%global build_pgsql 1}}
%{?_without_pgsql: %{expand: %%global build_pgsql 0}}
%{?_with_sasl: %{expand: %%global build_sasl 1}}
%{?_without_sasl: %{expand: %%global build_sasl 0}}

# TODO
# add configurable ssl support, unfortunately --without-ssl doesn't work if
# openssl-devel package is installed

Summary:	Secure IMAP and POP3 server
Name: 		dovecot
Version:	1.1.13
Release:	%mkrel 1
License:	MIT and LGPLv2 and BSD-like and Public Domain
Group:		System/Servers
URL:		http://dovecot.org
Source0:	http://dovecot.org/releases/1.1/%{name}-%{version}.tar.gz
Source1:	http://dovecot.org/releases/1.1/%{name}-%{version}.tar.gz.sig
Source2:	%{name}-pamd
Source3:	%{name}-init
Source4:	http://dovecot.org/tools/migration_wuimp_to_dovecot.pl
Source5:	http://dovecot.org/tools/mboxcrypt.pl
# sieve plugin. Must be updated when minor version increases.
Source6:	http://www.dovecot.org/releases/sieve/dovecot-sieve-1.1.6.tar.gz
Source7:    http://www.earth.ox.ac.uk/~steve/sieve/procmail2sieve.pl
Patch0:		dovecot-conf-ssl.patch
Patch1:		dovecot-sieve-1.1.6-compil_fix.diff
Provides:	imap-server pop3-server
Provides:	imaps-server pop3s-server
Requires(pre):	rpm-helper >= 0.21
Requires(post):	rpm-helper >= 0.19
Requires(preun): rpm-helper >= 0.19
Requires(postun): rpm-helper >= 0.19
BuildRequires:	pam-devel
BuildRequires:	openssl-devel
%if %{build_ldap}
BuildRequires:	openldap-devel
%endif
%if %{build_lucene}
BuildRequires:	clucene-devel
%endif
%if %{build_sasl}
BuildRequires:	libsasl-devel
%endif
%if %{build_mysql}
BuildRequires:	mysql-devel
%endif
%if %{build_pgsql}
BuildRequires:	postgresql-devel
%endif
%if %{build_gssapi}
BuildRequires:	gssglue-devel
BuildRequires:	krb5-devel
%endif
BuildRequires:	rpm-helper >= 0.21
BuildRequires:	bzip2-devel
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Dovecot is an IMAP and POP3 server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses several
coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail clients
accessing the mailboxes directly.

You can build %{name} with some conditional build swithes;

(ie. use with rpm --rebuild):

    --with[out] gssapi	GSSAPI support (enabled)
    --with[out] ldap	LDAP support (enabled)
    --with[out] lucene	Lucene support (enabled)
    --with[out] mysql	MySQL support (enabled)
    --with[out] pgsql	PostgreSQL support (enabled)
    --with[out] sasl	Cyrus SASL 2 library support (enabled)

%if %{build_ldap}
%package	plugins-ldap
Summary:	LDAP support for dovecot
Group:		System/Servers
Requires:	%{name} = %{version}

%description	plugins-ldap
This package provides LDAP capabilities to dovecot in a modular form.
%endif

%if %{build_gssapi}
%package	plugins-gssapi
Summary:	GSSAPI support for dovecot
Group:		System/Servers
Requires:	%{name} = %{version}

%description	plugins-gssapi
This package provides GSSAPI capabilities to dovecot in a modular form.
%endif

%package	devel
Summary:	Devel files for Dovecot IMAP and POP3 server
Group:		Development/C
Requires:	%{name} = %{version}

%description	devel
Dovecot is an IMAP and POP3 server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses several
coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail clients
accessing the mailboxes directly.

This package contains development files for dovecot.

%prep

%setup -q -a 6
# Bug #27491
%patch0 -p0 -b .sslfix

pushd dovecot-sieve-*
%patch1 -p0
popd

%build
%serverbuild

%configure2_5x \
    --with-ssl=openssl \
    --with-ssldir=%{_sysconfdir}/ssl/%{name} \
    --with-moduledir=%{_libdir}/%{name}/modules \
    --with-nss \
%if %{build_ldap}
    --with-ldap=plugin \
%endif
%if %{build_pgsql}
    --with-sql \
    --with-pgsql \
%endif
%if %{build_mysql}
    --with-sql \
    --with-mysql \
%endif
%if %{build_sasl}
    --with-cyrus-sasl2 \
%endif
%if %{build_gssapi}
    --with-gssapi=plugin \
%endif
%if %{build_lucene}
    --with-lucene \
%endif

%make

#build sieve plugin
pushd dovecot-sieve-*
%configure2_5x --with-dovecot=../
%make
popd

%install
rm -rf %{buildroot}

install -d %{buildroot}%{_sysconfdir}/pam.d
install -d %{buildroot}%{_initrddir}
install -d %{buildroot}%{_libdir}/%{name}/modules
install -d %{buildroot}/var/lib/%{name}

%makeinstall_std

pushd dovecot-sieve-*
%makeinstall_std
popd

cat %{SOURCE2} > %{buildroot}%{_sysconfdir}/pam.d/%{name}
cat %{SOURCE3} > %{buildroot}%{_initrddir}/%{name}
chmod 0755 %{buildroot}%{_initrddir}/%{name}
cp dovecot-example.conf %{buildroot}%{_sysconfdir}/dovecot.conf
cp %{SOURCE4} .
cp %{SOURCE5} .
# procmail2sieve converter
install -d -m 755 %{buildroot}%{_bindir}
install %{SOURCE7} -m 755 %{buildroot}%{_bindir}
perl -pi -e 's|#!/usr/local/bin/perl|#!%{_bindir}/perl|' \
    %{buildroot}%{_bindir}/procmail2sieve.pl

# placed in doc
rm -f %{buildroot}%{_sysconfdir}/dovecot*-example.conf

# Clean up buildroot
rm -rf %{buildroot}%{_datadir}/doc/dovecot/

%pre
%_pre_useradd dovecot /var/lib/%{name} /bin/false
%_pre_groupadd dovecot dovecot

%post
%_post_service dovecot
%_create_ssl_certificate dovecot

%preun
%_preun_service dovecot

%postun
%_postun_userdel dovecot
%_postun_groupdel dovecot

%post plugins-ldap
%{_initrddir}/%{name} condrestart > /dev/null 2>&1 || :

%postun plugins-ldap
if [ "$1" = "0" ]; then
    %{_initrddir}/%{name} condrestart > /dev/null 2>&1 || :
fi

%post plugins-gssapi
%{_initrddir}/%{name} condrestart > /dev/null 2>&1 || :

%postun plugins-gssapi
if [ "$1" = "0" ]; then
    %{_initrddir}/%{name} condrestart > /dev/null 2>&1 || :
fi

%clean
rm -rf %{buildroot}

%files
# to preserve security of the ssl password which may be in the config
# file but also allow the use of the 'deliver' command as any user,
# we set the 'deliver' command sgid mail and have the config file owned
# by root.mail. See bug #44926. idea from Josh Bressers at Red Hat.
# - AdamW 2008/10
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING* NEWS README TODO
%doc doc/*.conf doc/*.sh doc/*.txt doc/*.cnf
%doc mboxcrypt.pl migration_wuimp_to_dovecot.pl
%attr(0755,root,root) %{_initrddir}/%{name}
%attr(0640,root,mail) %config(noreplace) %{_sysconfdir}/dovecot.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%{_sbindir}/*
%{_bindir}/procmail2sieve.pl
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/checkpassword-reply
%{_libdir}/%{name}/convert-tool
%attr(2755,root,mail) %{_libdir}/%{name}/deliver
%{_libdir}/%{name}/dict
%{_libdir}/%{name}/dovecot-auth
%{_libdir}/%{name}/expire-tool
%{_libdir}/%{name}/gdbhelper
%{_libdir}/%{name}/idxview
%{_libdir}/%{name}/imap
%{_libdir}/%{name}/imap-login
%{_libdir}/%{name}/listview
%{_libdir}/%{name}/logview
%{_libdir}/%{name}/maildirlock
%{_libdir}/%{name}/pop3
%{_libdir}/%{name}/pop3-login
%{_libdir}/%{name}/rawlog
%{_libdir}/%{name}/sievec
%{_libdir}/%{name}/sieved
%{_libdir}/%{name}/ssl-build-param
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/*.so
%{_libdir}/%{name}/modules/pop3/*.so
%{_libdir}/%{name}/modules/lda/*.so
%{_libdir}/%{name}/modules/imap/*.so
%attr(0700,root,root) %dir /var/lib/%{name}

%files devel
%defattr(0755, root, root, 0755)
%{_libdir}/%{name}/modules/*.*a
%{_libdir}/%{name}/modules/imap/*.*a
%{_libdir}/%{name}/modules/auth/*.*a
%{_libdir}/%{name}/modules/lda/*.*a

%if %{build_ldap}
%files plugins-ldap
%defattr(-,root,root)
%{_libdir}/%{name}/modules/auth/libauthdb_ldap.so
%endif

%if %{build_gssapi}
%files plugins-gssapi
%defattr(-,root,root)
%{_libdir}/%{name}/modules/auth/libmech_gssapi.so
%endif


%changelog
* Thu Mar 19 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.13-1mdv2009.1
+ Revision: 357723
- update to new version 1.1.13

* Tue Mar 17 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.12-1mdv2009.1
+ Revision: 356874
- update to new version 1.1.12

* Thu Feb 05 2009 Michael Scherer <misc@mandriva.org> 1.1.11-1mdv2009.1
+ Revision: 337739
- update to 1.1.11
- fix dovecot-sieve compilation

* Mon Feb 02 2009 Jérôme Soyer <saispo@mandriva.org> 1.1.10-1mdv2009.1
+ Revision: 336528
- New upstream release

* Wed Jan 14 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.1.8-2mdv2009.1
+ Revision: 329402
- add procmail to sieve conversion tool

* Fri Jan 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.1.8-1mdv2009.1
+ Revision: 327528
- dovecot-1.1.8
- dovecot-sieve-1.1.6

* Wed Dec 17 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.7-2mdv2009.1
+ Revision: 315214
- rediffed one fuzzy patch

* Mon Dec 08 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.7-1mdv2009.1
+ Revision: 311826
- 1.1.7

* Sat Dec 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.6-3mdv2009.1
+ Revision: 311198
- rebuilt against mysql-5.1.30 libs

* Wed Nov 05 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.6-2mdv2009.1
+ Revision: 300121
- fix the permission stuff again (numeric mode in filelist was overriding the
  earlier chmod command)

* Wed Nov 05 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.6-1mdv2009.1
+ Revision: 300041
- 1.1.6

* Wed Nov 05 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.4-5mdv2009.1
+ Revision: 299971
- set deliver to be group mail (forgot in last commit)

* Tue Nov 04 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.4-4mdv2009.1
+ Revision: 299933
- implement nifty dodge for permissions issues relating to #44926 (see comment)

* Fri Oct 24 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.4-3mdv2009.1
+ Revision: 296857
- fix non-parallel init for the ntpd issue too

* Fri Oct 24 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.4-2mdv2009.1
+ Revision: 296853
- add should-start ntpd to initscript (fabrice facorat, #45035)
- dovecot.conf needs to be 644 not 640 (#44926)

* Wed Oct 15 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.4-1mdv2009.1
+ Revision: 293893
- 1.1.4

* Sun Sep 07 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.3-3mdv2009.0
+ Revision: 282240
- 0755 for initscript not 0700

* Sun Sep 07 2008 Adam Williamson <awilliamson@mandriva.org> 1.1.3-2mdv2009.0
+ Revision: 282065
- ensure initscript has 0700 permissions (twice, belt and braces!) #41788

* Thu Sep 04 2008 Jérôme Soyer <saispo@mandriva.org> 1.1.3-1mdv2009.0
+ Revision: 280492
- New release

* Fri Aug 15 2008 Michael Scherer <misc@mandriva.org> 1.1.2-1mdv2009.0
+ Revision: 272216
- new version
- fix source url

* Thu Jun 26 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.1-0.2mdv2009.0
+ Revision: 229256
- nss had nothing to do with nss-devel :-)
- enable everything per default
- fix conditionals
- reload dovecot if needed for the plugins sub packages
- added lsm headers

* Wed Jun 25 2008 Oden Eriksson <oeriksson@mandriva.com> 1.1.1-0.1mdv2009.0
+ Revision: 229123
- 1.1.1
- reworked the conditional magic
- the ldap and gssapi functionalities has been broken
  out to subpackages, dovecot-plugins-ldap and dovecot-plugins-gssapi
- the modulesdir should not be %%{_datadir}/%%{name} but in fact
  %%{_libdir}/%%{name}/modules

* Fri Jun 13 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.14-1mdv2009.0
+ Revision: 218841
- 1.0.14

* Mon Mar 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.13-1mdv2008.1
+ Revision: 183490
- 1.0.13 (Minor security fixes)

* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.12-2mdv2008.1
+ Revision: 180930
- fix #38615

* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.12-1mdv2008.1
+ Revision: 180856
- 1.0.12

* Fri Feb 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.10-4mdv2008.1
+ Revision: 168821
- versionned build dependency on rpm-helper

* Tue Jan 29 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.10-3mdv2008.1
+ Revision: 159934
- use new create ssl certificate helper macro interface

* Mon Jan 28 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.10-2mdv2008.1
+ Revision: 159425
- add sieve plugin (#32581)

* Tue Jan 15 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.10-1mdv2008.1
+ Revision: 153290
- 1.0.10

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.9-2mdv2008.1
+ Revision: 137504
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Jérôme Soyer <saispo@mandriva.org> 1.0.9-1mdv2008.1
+ Revision: 119730
- New release 1.0.9

* Tue Dec 04 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.8-1mdv2008.1
+ Revision: 115393
- 1.0.8

* Tue Nov 06 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.7-1mdv2008.1
+ Revision: 106384
- 1.0.7

* Mon Sep 17 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.5-1mdv2008.0
+ Revision: 89292
- 1.0.5

* Fri Aug 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.3-4mdv2008.0
+ Revision: 64673
- use ssl certs creation helpers

  + Tibor Pittich <tibor@mandriva.com>
    - fixed Bug #27491 and #27561

* Thu Aug 16 2007 Tibor Pittich <tibor@mandriva.com> 1.0.3-2mdv2008.0
+ Revision: 64136
- increase release number
- really enable ldap support
- fix with/without rpm build options, fix dexcription

* Wed Aug 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.3-1mdv2008.0
+ Revision: 63642
- 1.0.3

* Thu Aug 02 2007 Adam Williamson <awilliamson@mandriva.org> 1.0.2-4mdv2008.0
+ Revision: 58315
- BuildRequires krb5-devel for gssapi build
- use Fedora licensing policy (licensing on this app is insane, this is a good way to handle it)

* Fri Jul 27 2007 Adam Williamson <awilliamson@mandriva.org> 1.0.2-3mdv2008.0
+ Revision: 56127
- build with support for GSSAPI authentication (bug #32112)

* Tue Jul 17 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.2-2mdv2008.0
+ Revision: 52872
- fix rpm-helper Requires(post,preun) and such
- fix deps
- 1.0.2

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 1.0.1-2mdv2008.0
+ Revision: 45127
- using serverbuild macro (-fstack-protector-all)

  + Adam Williamson <awilliamson@mandriva.org>
    - adjust ssl stuff as advised by guillaume (#27561)

* Fri Jun 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.1-1mdv2008.0
+ Revision: 40141
- 1.0.1

* Tue Jun 12 2007 Adam Williamson <awilliamson@mandriva.org> 1.0.0-2mdv2008.0
+ Revision: 38341
- install /etc/pki/dovecot/dovecot-openssl.cnf (bug #27561)
- argh, wrong branch! revert
- import 2007 package to updates

* Tue May 01 2007 Michael Scherer <misc@mandriva.org> 1.0.0-1mdv2008.0
+ Revision: 19904
- upgrade to 1.0.0 ( at last )

* Sat Apr 21 2007 Anssi Hannula <anssi@mandriva.org> 1.0.rc26-2mdv2008.0
+ Revision: 16707
- migrate away from deprecated pam_stack.so


* Tue Mar 13 2007 Jérôme Soyer <saispo@mandriva.org> 1.0.rc26-1mdv2007.1
+ Revision: 142202
- New RC

* Sun Mar 04 2007 Michael Scherer <misc@mandriva.org> 1.0.rc25-1mdv2007.1
+ Revision: 131924
- update to 1.0.rc25

* Fri Jan 12 2007 Michael Scherer <misc@mandriva.org> 1.0.rc17-1mdv2007.1
+ Revision: 107793
- upgrade to rc17

* Wed Nov 29 2006 Michael Scherer <misc@mandriva.org> 1.0.rc15-1mdv2007.1
+ Revision: 88778
- use default upstream configuration file
- bunzip patch
- upgrade to 1.0.rc15
- Import dovecot

* Tue Sep 05 2006 Jerome Soyer <saispo@mandriva.org> 1.0.rc7.1mdv2007.0
- new version

* Thu Jul 13 2006 Nicolas Chipaux <chipaux@mandriva.com> 1.0.rc2.1mdv2007.0
- new version
- split in devel rpm

* Mon Jun 26 2006 Nicolas Chipaux <chipaux@mandriva.com> 1.09.beta9.1mdv2007.0
- new version

* Tue May 30 2006 Jerome Soyer <saispo@mandriva.org> 0.99.14-4mdv2007.0
- CVE-2006-2414 
- use mkrel

* Wed Nov 30 2005 Oden Eriksson <oeriksson@mandriva.com> 0.99.14-3mdk
- rebuilt against openssl-0.9.8a

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 0.99.14-2mdk
- rebuilt against new openldap-2.3.6 libs

* Fri Mar 18 2005 Michael Scherer <misc@mandrake.org> 0.99.14-1mdk
- New release 0.99.14
- better summary
- add some tools in %%doc

* Fri Feb 04 2005 Michael Scherer <misc@mandrake.org> 0.99.12-2mdk
- Rebuild new ldap

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.99.12-1mdk
- New release 0.99.12

* Wed Aug 11 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 0.99.10.9-2mdk
- fix init script to make rpmlint happy
- create switches to allow/deny some features and and describe it in
  description
- update url
- by default disable pgsql support, added configurable support for mysql
- change provides to pop3-server and add imaps and pop3s-server provides
- minimalize number of nonstandard permission in files
- some other spec changes, macroszification

* Tue Aug 10 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 0.99.10.9-1mdk
- 0.99.10.9

* Thu Jul 15 2004 Michael Scherer <misc@mandrake.org> 0.99.10.7-1mdk 
- 0.99.10.7
- rpmbuildupdate aware

* Wed Jul 14 2004 Michael Scherer <misc@mandrake.org> 0.99.10.6-1mdk
- New release 0.99.10.6
- replaced the patch on conf by a source file
- fix BuildRequires, and init script ( from Michael Reinsch <mr@uue.org> )
- remove implicit requires, added new provides scheme
- remove service restart on upgrade, as it is already done by spec-helper

